==> haskell-x11-xft-0.3.4-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11-xft
version:              0.3.4
visibility:           public
id:                   X11-xft-0.3.4-98YLZVy2qHCY5tIyZFoYm
key:                  X11-xft-0.3.4-98YLZVy2qHCY5tIyZFoYm
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:               Clemens Fruhwirth
synopsis:             Bindings to the Xft and some Xrender parts
description:
    A Haskell bindings to the X Font library. With it, Haskell X11
    applications can access high quality font renderings and provide
    fonts with anti-aliasing and subpixel rendering. The bindings
    also provide minimal bindings to Xrender parts.

category:             Graphics
abi:                  a3c60b9df61cf59d16654057483c5428
exposed:              True
exposed-modules:      Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:          /usr/lib/ghc-9.2.8/site-local/X11-xft-0.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/X11-xft-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x11-xft
hs-libraries:         HSX11-xft-0.3.4-98YLZVy2qHCY5tIyZFoYm
extra-libraries:      Xft
include-dirs:
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    X11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu base-4.16.4.0
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:   /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:         /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.4-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11-xft
version:              0.3.4
visibility:           public
id:                   X11-xft-0.3.4-Ia6yRbDM6qbIQWxH9Pzr7B
key:                  X11-xft-0.3.4-Ia6yRbDM6qbIQWxH9Pzr7B
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:               Clemens Fruhwirth
synopsis:             Bindings to the Xft and some Xrender parts
description:
    A Haskell bindings to the X Font library. With it, Haskell X11
    applications can access high quality font renderings and provide
    fonts with anti-aliasing and subpixel rendering. The bindings
    also provide minimal bindings to Xrender parts.

category:             Graphics
abi:                  6b8da8cb7d8835d4aba8602d6cbaa3d2
exposed:              True
exposed-modules:      Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:          /usr/lib/ghc-9.2.8/site-local/X11-xft-0.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/X11-xft-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x11-xft
hs-libraries:         HSX11-xft-0.3.4-Ia6yRbDM6qbIQWxH9Pzr7B
extra-libraries:      Xft
include-dirs:
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    X11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu base-4.16.4.0
    utf8-string-1.0.2-CndrelvclEbJyymwdX0DqC

haddock-interfaces:   /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:         /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
